@@ -7,9 +7,9 @@ import uuid
 import warnings
 from copy import deepcopy
 from enum import Enum, auto
-from pathlib import Path, PurePath, PosixPath
+from pathlib import Path, PosixPath, PurePath
 from textwrap import dedent
-from typing import Dict, List, Optional, Tuple, Generator, Any, Iterable, Union
+from typing import Any, Dict, Generator, Iterable, List, Optional, Tuple, Union
 from urllib.parse import urlsplit
 
 import numpy
@@ -21,17 +21,12 @@ from rasterio.enums import Resampling
 from shapely.geometry.base import BaseGeometry
 
 import eodatasets3
-from eodatasets3 import serialise, validate, images, documents
+from eodatasets3 import documents, images, serialise, validate
 from eodatasets3.documents import find_and_read_documents
 from eodatasets3.images import FileWrite, GridSpec, MeasurementBundler
-from eodatasets3.model import (
-    DatasetDoc,
-    ProductDoc,
-    Location,
-    AccessoryDoc,
-)
-from eodatasets3.names import NamingConventions, namer, resolve_location, dc_uris
-from eodatasets3.properties import Eo3Interface, Eo3Dict
+from eodatasets3.model import AccessoryDoc, DatasetDoc, Location, ProductDoc
+from eodatasets3.names import NamingConventions, dc_uris, namer, resolve_location
+from eodatasets3.properties import Eo3Dict, Eo3Interface
 from eodatasets3.validate import Level, ValidationMessage
 from eodatasets3.verify import PackageChecksum
 
@@ -468,9 +463,9 @@ class DatasetPrepare(Eo3Interface):
 
     @property
     def measurements(self) -> Dict[str, Tuple[GridSpec, Path]]:
-        return dict(
-            (name, (grid, path)) for grid, name, path in self._measurements.iter_paths()
-        )
+        return {
+            name: (grid, path) for grid, name, path in self._measurements.iter_paths()
+        }
 
     @property
     def label(self) -> Optional[str]:
@@ -753,7 +748,7 @@ class DatasetPrepare(Eo3Interface):
         sort_measurements: bool = True,
     ) -> Tuple[uuid.UUID, Path]:
         """Write the prepared metadata document to the given output path."""
-        metadata_path = path or (self._target_metadata_path())
+        metadata_path = path or self._target_metadata_path()
         dataset_location = self.names.dataset_location
 
         # Default behaviour:
@@ -1201,6 +1196,7 @@ class DatasetAssembler(DatasetPrepare):
         self,
         name: str,
         input_path: Location,
+        index: Optional[int] = None,
         overviews: Iterable[int] = images.DEFAULT_OVERVIEWS,
         overview_resampling: Resampling = Resampling.average,
         expand_valid_data: bool = True,
@@ -1214,6 +1210,7 @@ class DatasetAssembler(DatasetPrepare):
 
         :param name: Identifier for the measurement eg ``'blue'``.
         :param input_path: The image to read
+        :param index: Which index to read from the image, if it contains more than one.
         :param overviews: Set of overview sizes to write
         :param overview_resampling: rasterio Resampling method to use
         :param expand_valid_data: Include this measurement in the valid-data geometry of the metadata.
@@ -1226,6 +1223,7 @@ class DatasetAssembler(DatasetPrepare):
             self.write_measurement_rio(
                 name,
                 ds,
+                index=index,
                 overviews=overviews,
                 expand_valid_data=expand_valid_data,
                 overview_resampling=overview_resampling,
@@ -1237,6 +1235,7 @@ class DatasetAssembler(DatasetPrepare):
         self,
         name: str,
         ds: DatasetReader,
+        index: Optional[int] = None,
         overviews=images.DEFAULT_OVERVIEWS,
         overview_resampling=Resampling.average,
         expand_valid_data=True,
@@ -1247,17 +1246,18 @@ class DatasetAssembler(DatasetPrepare):
         Write a measurement by reading it from an open rasterio dataset
 
         :param ds: An open rasterio dataset
+        :param index: Which index to read from the image, if it contains more than one.
 
         See :func:`write_measurement` for other parameters.
         """
-        if len(ds.indexes) != 1:
-            raise NotImplementedError(
-                f"TODO: Multi-band images not currently implemented (have {len(ds.indexes)})"
+        if len(ds.indexes) != 1 and not index:
+            raise ValueError(
+                f"Image has {len(ds.indexes)} indexes to choose from, but index wasn't specified."
             )
 
         self._write_measurement(
             name,
-            ds.read(1),
+            ds.read(index or 1),
             images.GridSpec.from_rio(ds),
             self._work_path
             / (path or self.names.measurement_filename(name, "tif", file_id=file_id)),
@@ -1443,7 +1443,7 @@ class DatasetAssembler(DatasetPrepare):
                 )
             )
         rgbs = [self.measurements[b] for b in (red, green, blue)]
-        unique_grids: List[GridSpec] = list(set(grid for grid, path in rgbs))
+        unique_grids: List[GridSpec] = list({grid for grid, path in rgbs})
         if len(unique_grids) != 1:
             raise NotImplementedError(
                 "Thumbnails can only currently be created from measurements of the same grid spec."
@@ -1607,7 +1607,7 @@ class DatasetAssembler(DatasetPrepare):
                 "being ignored).",
                 category=DeprecationWarning,
             )
-            return super(DatasetAssembler, self).done(
+            return super().done(
                 embed_location=embed_location,
                 validate_correctness=validate_correctness,
                 sort_measurements=sort_measurements,
@@ -1701,6 +1701,9 @@ class DatasetAssembler(DatasetPrepare):
                 )
 
         target_metadata_path = self._target_metadata_path()
-        assert target_metadata_path.exists()
+        if not target_metadata_path.exists():
+            raise RuntimeError(
+                f"Internal error: expected metadata path result: {target_metadata_path}"
+            )
         self._is_completed = True
         return dataset.id, target_metadata_path
